---
title: <span class="badge object-type-scalar"></span> VoltAmpereReactive
---
# <span class="badge object-type-scalar"></span> VoltAmpereReactive

Energy: Volt-Ampere reactive (VAr)

## Definition

```python
# Energy: Volt-Ampere reactive (VAr)
VoltAmpereReactive: typing.Literal["voltampreact"] = "voltampreact"
```
